# tosspay-py
사업자 등록증 없이 결제 시스템을 만들수있는 라이브러리

> [!IMPORTANT]  
> 이 라이브러리를 사용하기 위해서는 토스아이디(toss-id)가 필요합니다
> ![](https://github.com/tosspay-lib/tosspay-rs/blob/main/img/important.png?raw=true)


## on_payment
특정 유저가 보낸돈만 확인할때만 사용합니다 <br/>
[자세히보기 >](./docs/on_payment.md)

## on_donate
모든 사용자가 보낸 후원 내역을 확인합니다. <br/>
[자세히보기 >](./docs/on_donate.md)

## payment
특정 유저가 보낸돈만 확인할때만 사용합니다 <br/>
[자세히보기 >](./docs/payment.md)

## donate
모든 사용자가 보낸 후원 내역을 확인합니다. <br/>
[자세히보기 >](./docs/donate.md)